import { isEmpty } from '@cip/utils/util'
const transformSuccessResponse = (response) => {
  if (response?.data && !(response.data instanceof Blob)) {
    const transData = {}
    const { msg, status, code, data } = response.data
    if (msg) transData.message = msg
    transData.code = isEmpty(code) ? status : code
    // 在特殊情况下code与status同时存在切需要使用status
    transData.status = status
    if (data?.data) {
      // 接收参数转换
      const offset = (data.page.pageNum - 1) * data.page.pageSize
      transData.pageNum = data.page.pageNum
      transData.limit = data.page.pageSize
      transData.total = data.page.total
      // 返回offset异常会导致table组件塌缩
      transData.offset = isNaN(offset) ? 0 : offset
      transData.data = data.data
    } else {
      transData.data = data
    }
    response.data = transData
  }
  return response
}

export const smartCenterInterceptors = (axios) => {
  // 转换分页参数
  axios.interceptors.request.use(config => {
    const { params } = config
    if (params) {
      config.params.pageNum = params.limit ? (params.offset / params.limit) + 1 : undefined
      config.params.pageSize = params.limit
      config.params.limit = undefined
      config.params.offset = undefined
    }
    return config
  }, err => {
    return Promise.reject(err)
  })

  // 转换数据结构
  axios.interceptors.response.use(response => {
    return transformSuccessResponse(response)
  }, err => {
    if (err && err.response) {
      const errorMessage =
        err.response?.data?.data?.msg ||
        err.response?.data?.msg
      // 将错误信息转换为message供下次处理
      err.response.data.message = errorMessage
    }
    return Promise.reject(err)
  })
}
