import { computed, watch, defineComponent, onMounted, h, ref, watchEffect } from 'vue'
import { formInputProps, fromInputEmits } from '@cip/components/cip-form-input/form-input-props'
import BasicSelect from '@cip/components/cip-form-input/basic/select'
import BasicCheckBox from '@cip/components/cip-form-input/basic/checkbox'
import BasicRadio from '@cip/components/cip-form-input/basic/radio'
import { dictionaryService } from '@/api'
// 逻辑简化版接口select
export default defineComponent({
  name: 'BasicDataDictionary',
  props: formInputProps,
  emits: fromInputEmits,
  setup (props, context) {
    const inputRef = ref()
    onMounted(() => {
      watch(() => props.config.dictionaryCode, () => {
        inputRef.value?.getOptions()
      })
    })

    const asyncOptions = async () => {
      if (!props.config.dictionaryCode) return []
      const { data } = await dictionaryService.list({ dictionaryCode: props.config.dictionaryCode })
      return data || []
    }
    const rewriteConfig = computed(() => {
      const originConfig = props.config
      originConfig.asyncOptions = asyncOptions
      return originConfig
    })
    const getComponentByViewType = (viewType = 'select') => {
      switch (viewType) {
        case 'radio': return BasicRadio
        case 'checkbox': return BasicCheckBox
        default: return BasicSelect
      }
    }
    return () => h(getComponentByViewType(props.config.viewType), {
      ref: inputRef,
      ...props,
      'onStreamUpdate:model': (val) => context.emit('streamUpdate:model', val),
      config: rewriteConfig.value
    })
  }
})
